import click
import requests
from taos.web import scrape
from taos import bio

@click.group()
@click.pass_context
def main(ctx):
    pass


@main.command()
def about():
    """ Print information about Taos """
    print("about")
    scrape("urls")


@click.option("--name", prompt="What is your name?", help="Name submitted to taos contacts.")
@click.option("--email", prompt="What is your Email?", help="Email submitted to taos contacts.")
@click.option(
    "--service-type",
    prompt="which services are you interested in <provide a list of MS PS NOC DON etc>?",
    help="Type of support services that you are interested in."
)
@main.command()
def contact(name, email, service_type):
    """ Send a contact request to taos """
    print(f"contact, {name}, {email}, {service_type}")
    print(f"<A HREF mailto:contact@taos.com>TEST</A>")


@main.command()
def subscribe():
    """ Send a service subscription request to taos """
    print("subscribe")


@main.command("bio")
@click.argument("user", type=click.Choice(bio.list_persons()))
def bio_get(user):
    """ Lookup Taos personell bio information. """
    click.echo(f"{user} BIO \n")
    click.echo(bio.get_user(user))



from bs4 import BeautifulSoup
from typing import List
from taos import config
import requests

search_string = '/taosdevops/dev-ops-now-bios/blob/master/team-members/'
def is_member(tag):
  return (tag.name == 'a') and \
        (tag.has_attr('href') and search_string in tag['href'])

def _get_from_gh():
    url = "https://github.com/taosdevops/dev-ops-now-bios/tree/master/team-members"
    response = requests.get(url, headers={'User-Agent': config.USER_AGENT})
    soup = BeautifulSoup(response.text, "html.parser")
    members = soup.findAll(is_member)
    return [item.string[:-3] for item in members]

def list_persons()-> List[str]:
    return _get_from_gh()

def get_user(user: str)-> dict:
    url = (
        "https://raw.githubusercontent.com/taosdevops/dev-ops-now-bios/"
        f"master/team-members/{user}.md"
    )
    return requests.get(url).content



from setuptools import find_packages, setup

setup(
    author="TAOS DevopsNow",
    name="taos",
    author_email="devopsnow@taos.com",
    description="Taos Command Line",
    #license=open("LICENSE").read(),
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    packages=find_packages(exclude=["contrib", "docs", "tests"]),
    version="1.0.1",
    url="https://github.com/taosdevops/taos",
    install_requires=[
        "Click==7.0",
    ],
    entry_points="""
        [console_scripts]
        taos=taos.cli:main
        """,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',  # Your supported Python ranges
)
